==> v3.5.13.zip: kaffeine/kaffeine/src/player-parts/xine-part/equalizer.h <==
/*
 * equalizer.h
 *
 * Copyright (C) 2003-2004 Jürgen Kofler <kaffeine@gmx.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef ETQUALIZER_H
#define ETQUALIZER_H

#include <kdialogbase.h>
#include <kconfig.h>

#include <tqwidget.h>
#include <tqslider.h>
#include <tqgroupbox.h>
#include <tqcheckbox.h>

/**equalizer widget
  *@author Juergen  Kofler
  */

class Equalizer : public KDialogBase  {
   Q_OBJECT
  TQ_OBJECT
public: 
  Equalizer(TQWidget *parent=0, const char *name=0);
  ~Equalizer();

  void ReadValues(KConfig* config);
  void SaveValues(KConfig* config);

signals:
  void signalNewEq30(int);
  void signalNewEq60(int);
  void signalNewEq125(int);
  void signalNewEq250(int);
  void signalNewEq500(int);
  void signalNewEq1k(int);
  void signalNewEq2k(int);
  void signalNewEq4k(int);
  void signalNewEq8k(int);
  void signalNewEq16k(int);
  void signalSetVolumeGain(bool);

  
private slots:
  void slotSetDefaultValues();
  void slotSetEnabled( bool );

private:
  TQCheckBox* on;
  TQCheckBox* volumeGain;
  TQGroupBox* equalGroup;
  TQSlider* eq30Slider;
  TQSlider* eq60Slider;
  TQSlider* eq125Slider;
  TQSlider* eq250Slider;
  TQSlider* eq500Slider;
  TQSlider* eq1kSlider;
  TQSlider* eq2kSlider;
  TQSlider* eq4kSlider;
  TQSlider* eq8kSlider;
  TQSlider* eq16kSlider;
};

#endif /* ETQUALIZER_H */

==> r14.0.9.zip: kaffeine/kaffeine/src/player-parts/xine-part/equalizer.h <==
/*
 * equalizer.h
 *
 * Copyright (C) 2003-2004 Jürgen Kofler <kaffeine@gmx.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef EQUALIZER_H
#define EQUALIZER_H

#include <kdialogbase.h>
#include <tdeconfig.h>

#include <tqwidget.h>
#include <tqslider.h>
#include <tqgroupbox.h>
#include <tqcheckbox.h>

/**equalizer widget
  *@author Juergen  Kofler
  */

class Equalizer : public KDialogBase  {
   Q_OBJECT
  
public: 
  Equalizer(TQWidget *parent=0, const char *name=0);
  ~Equalizer();

  void ReadValues(TDEConfig* config);
  void SaveValues(TDEConfig* config);

signals:
  void signalNewEq30(int);
  void signalNewEq60(int);
  void signalNewEq125(int);
  void signalNewEq250(int);
  void signalNewEq500(int);
  void signalNewEq1k(int);
  void signalNewEq2k(int);
  void signalNewEq4k(int);
  void signalNewEq8k(int);
  void signalNewEq16k(int);
  void signalSetVolumeGain(bool);

  
private slots:
  void slotSetDefaultValues();
  void slotSetEnabled( bool );

private:
  TQCheckBox* on;
  TQCheckBox* volumeGain;
  TQGroupBox* equalGroup;
  TQSlider* eq30Slider;
  TQSlider* eq60Slider;
  TQSlider* eq125Slider;
  TQSlider* eq250Slider;
  TQSlider* eq500Slider;
  TQSlider* eq1kSlider;
  TQSlider* eq2kSlider;
  TQSlider* eq4kSlider;
  TQSlider* eq8kSlider;
  TQSlider* eq16kSlider;
};

#endif /* EQUALIZER_H */
